@@ -1,18 +1,18 @@
 from base64 import b64decode
 import threading
-import json
+import atexit
 from pubcontrol import PubControl, Item, Format
 
 realm = None
 key = None
 ssl = True
 
-class FppFormat(Format):
+class JsonObjectFormat(Format):
 	def __init__(self, value):
 		self.value = value
 
 	def name(self):
-		return 'fpp'
+		return 'json-object'
 
 	def export(self):
 		return self.value
@@ -27,15 +27,15 @@ def _get_pubcontrol():
 			scheme = 'https'
 		else:
 			scheme = 'http'
-		pub = PubControl('%s://api.fanout.io/realm/%s' % (scheme, realm))
-		pub.set_auth_jwt({ 'iss': realm }, b64decode(key))
+		pub = PubControl({
+			'uri': '%s://api.fanout.io/realm/%s' % (scheme, realm),
+			'iss': realm,
+			'key': b64decode(key)
+		})
+		atexit.register(pub.finish)
 		_threadlocal.pubcontrol = pub
 	return _threadlocal.pubcontrol
 
-def publish(channel, data, id=None, prev_id=None):
+def publish(channel, data, id=None, prev_id=None, blocking=False, callback=None):
 	pub = _get_pubcontrol()
-	pub.publish(channel, Item(FppFormat(data), id, prev_id))
-
-def publish_async(channel, data, id=None, prev_id=None, callback=None):
-	pub = _get_pubcontrol()
-	pub.publish_async(channel, Item(FppFormat(data), id, prev_id), callback)
+	pub.publish(channel, Item(JsonObjectFormat(data), id, prev_id), blocking=blocking, callback=callback)
